==> camel-k-model-v1-6.0.0-sources.jar: io/fabric8/camelk/v1/IntegrationPlatformListFluent.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface IntegrationPlatformListFluent<A extends IntegrationPlatformListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,IntegrationPlatform item);
  public A setToItems(Integer index,IntegrationPlatform item);
  public A addToItems(io.fabric8.camelk.v1.IntegrationPlatform... items);
  public A addAllToItems(Collection<IntegrationPlatform> items);
  public A removeFromItems(io.fabric8.camelk.v1.IntegrationPlatform... items);
  public A removeAllFromItems(Collection<IntegrationPlatform> items);
  public A removeMatchingFromItems(Predicate<IntegrationPlatformBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<IntegrationPlatform> getItems();
  public List<IntegrationPlatform> buildItems();
  public IntegrationPlatform buildItem(Integer index);
  public IntegrationPlatform buildFirstItem();
  public IntegrationPlatform buildLastItem();
  public IntegrationPlatform buildMatchingItem(Predicate<IntegrationPlatformBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<IntegrationPlatformBuilder> predicate);
  public A withItems(List<IntegrationPlatform> items);
  public A withItems(io.fabric8.camelk.v1.IntegrationPlatform... items);
  public Boolean hasItems();
  public IntegrationPlatformListFluent.ItemsNested<A> addNewItem();
  public IntegrationPlatformListFluent.ItemsNested<A> addNewItemLike(IntegrationPlatform item);
  public IntegrationPlatformListFluent.ItemsNested<A> setNewItemLike(Integer index,IntegrationPlatform item);
  public IntegrationPlatformListFluent.ItemsNested<A> editItem(Integer index);
  public IntegrationPlatformListFluent.ItemsNested<A> editFirstItem();
  public IntegrationPlatformListFluent.ItemsNested<A> editLastItem();
  public IntegrationPlatformListFluent.ItemsNested<A> editMatchingItem(Predicate<IntegrationPlatformBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,IntegrationPlatformFluent<IntegrationPlatformListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> camel-k-model-v1-6.7.2-sources.jar: io/fabric8/camelk/v1/IntegrationPlatformListFluent.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface IntegrationPlatformListFluent<A extends IntegrationPlatformListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,IntegrationPlatform item);
  public A setToItems(int index,IntegrationPlatform item);
  public A addToItems(io.fabric8.camelk.v1.IntegrationPlatform... items);
  public A addAllToItems(Collection<IntegrationPlatform> items);
  public A removeFromItems(io.fabric8.camelk.v1.IntegrationPlatform... items);
  public A removeAllFromItems(Collection<IntegrationPlatform> items);
  public A removeMatchingFromItems(Predicate<IntegrationPlatformBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<IntegrationPlatform> getItems();
  public List<IntegrationPlatform> buildItems();
  public IntegrationPlatform buildItem(int index);
  public IntegrationPlatform buildFirstItem();
  public IntegrationPlatform buildLastItem();
  public IntegrationPlatform buildMatchingItem(Predicate<IntegrationPlatformBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<IntegrationPlatformBuilder> predicate);
  public A withItems(List<IntegrationPlatform> items);
  public A withItems(io.fabric8.camelk.v1.IntegrationPlatform... items);
  public Boolean hasItems();
  public IntegrationPlatformListFluent.ItemsNested<A> addNewItem();
  public IntegrationPlatformListFluent.ItemsNested<A> addNewItemLike(IntegrationPlatform item);
  public IntegrationPlatformListFluent.ItemsNested<A> setNewItemLike(int index,IntegrationPlatform item);
  public IntegrationPlatformListFluent.ItemsNested<A> editItem(int index);
  public IntegrationPlatformListFluent.ItemsNested<A> editFirstItem();
  public IntegrationPlatformListFluent.ItemsNested<A> editLastItem();
  public IntegrationPlatformListFluent.ItemsNested<A> editMatchingItem(Predicate<IntegrationPlatformBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,IntegrationPlatformFluent<IntegrationPlatformListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
